DESCRIPTION
===========
This is the core module and test suites/framework for MCUSH project.
It eases the test work and create CLI/GUI applications.
For more info about MCUSH, visit :
https://github.com/pengshulin/mcush/
http://www.linkongsoft.com/

LICENSE
=======
* Free only for non-commercial purpose.
* Commercial use NEED TO BE AUTHORIZED!!!
* Contact Shanghai Linkong Software Technologies Co., Ltd for commerical support.

AUTHOR
======
Peng Shulin <trees_peng@163.com>
Shanghai, China 2020

